@@ -1,7 +1,9 @@
 package Sah::Schema::unix::filename;
 
-our $DATE = '2021-07-19'; # DATE
-our $VERSION = '0.014'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-07-20'; # DATE
+our $DIST = 'Sah-Schemas-Unix'; # DIST
+our $VERSION = '0.015'; # VERSION
 
 our $schema = ["filename::unix" => {
     summary => 'File name (with optional path) on a Unix system',
@@ -13,7 +15,7 @@ _
 
     examples => [],
 
-}, {}];
+}];
 
 1;
 # ABSTRACT: File name (with optional path) on a Unix system
@@ -30,7 +32,7 @@ Sah::Schema::unix::filename - File name (with optional path) on a Unix system
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::unix::filename (from Perl distribution Sah-Schemas-Unix), released on 2021-07-19.
+This document describes version 0.015 of Sah::Schema::unix::filename (from Perl distribution Sah-Schemas-Unix), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
