@@ -1,7 +1,9 @@
 package Sah::Schema::unix::pid;
 
-our $DATE = '2021-07-19'; # DATE
-our $VERSION = '0.014'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-07-20'; # DATE
+our $DIST = 'Sah-Schemas-Unix'; # DIST
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [posint => {
     summary => 'Process identifier (PID)',
@@ -15,7 +17,7 @@ _
         {value=>1, valid=>1},
     ],
 
-}, {}];
+}];
 
 1;
 # ABSTRACT: Process identifier (PID)
@@ -32,7 +34,7 @@ Sah::Schema::unix::pid - Process identifier (PID)
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::unix::pid (from Perl distribution Sah-Schemas-Unix), released on 2021-07-19.
+This document describes version 0.015 of Sah::Schema::unix::pid (from Perl distribution Sah-Schemas-Unix), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
