@@ -1,20 +1,23 @@
 package Sah::Schema::unix::signal;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-19'; # DATE
+our $DATE = '2021-07-20'; # DATE
 our $DIST = 'Sah-Schemas-Unix'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = ['str' => {
     'summary' => 'Unix signal name (e.g. TERM or KILL) or number (9 or 15)',
     match => '\A(?:[A-Z]+[0-9]*|[1-9][0-9]*)\z',
     examples => [
+        # valid signals found in most Unix systems
+        qw/HUP INT QUIT ILL ABRT FPE KILL SEGV PIPE ALRM TERM USR1 USR2 CHLD CONT STOP TSTP TTIN TTOU/,
+        1..15,
+
+        # other tests
         {data=>'', valid=>0},
-        {data=>'HUP', valid=>1},
-        {data=>'1', valid=>1},
     ],
 _
-}, {}];
+}];
 
 1;
 # ABSTRACT: Unix signal name (e.g. TERM or KILL) or number (9 or 15)
@@ -31,7 +34,7 @@ Sah::Schema::unix::signal - Unix signal name (e.g. TERM or KILL) or number (9 or
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::unix::signal (from Perl distribution Sah-Schemas-Unix), released on 2021-07-19.
+This document describes version 0.015 of Sah::Schema::unix::signal (from Perl distribution Sah-Schemas-Unix), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
@@ -98,12 +101,76 @@ L<Perinci::CmdLine> to create a CLI:
 
 Sample data:
 
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
+ undef  # INVALID
+
  ""  # INVALID
 
- "HUP"  # valid
-
- 1  # valid
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Unix>.
