@@ -1,7 +1,9 @@
 package Sah::Schema::unix::username;
 
-our $DATE = '2021-07-19'; # DATE
-our $VERSION = '0.014'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-07-20'; # DATE
+our $DIST = 'Sah-Schemas-Unix'; # DIST
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [str => {
     summary => 'Unix account name',
@@ -31,7 +33,7 @@ _
         {value=>'a' x 33, value=>0, summary=>'Too long'},
     ],
 
-}, {}];
+}];
 
 1;
 # ABSTRACT: Unix account name
@@ -48,7 +50,7 @@ Sah::Schema::unix::username - Unix account name
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::unix::username (from Perl distribution Sah-Schemas-Unix), released on 2021-07-19.
+This document describes version 0.015 of Sah::Schema::unix::username (from Perl distribution Sah-Schemas-Unix), released on 2021-07-20.
 
 =head1 SYNOPSIS
 
