@@ -1,7 +1,7 @@
 package Sah::Schemas::Unix;
 
-our $DATE = '2021-07-19'; # DATE
-our $VERSION = '0.014'; # VERSION
+our $DATE = '2021-07-20'; # DATE
+our $VERSION = '0.015'; # VERSION
 
 1;
 # ABSTRACT: Various Sah schemas for Unix
@@ -18,13 +18,7 @@ Sah::Schemas::Unix - Various Sah schemas for Unix
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schemas::Unix (from Perl distribution Sah-Schemas-Unix), released on 2021-07-19.
-
-=head1 CONTRIBUTOR
-
-=for stopwords perlancar (on netbook-dell-xps13)
-
-perlancar (on netbook-dell-xps13) <perlancar@gmail.com>
+This document describes version 0.015 of Sah::Schemas::Unix (from Perl distribution Sah-Schemas-Unix), released on 2021-07-20.
 
 =head1 SAH SCHEMAS
 
